@@ -5,6 +5,7 @@ import threading
 import itertools
 import time
 import sys
+import requests
 
 import openai
 from jinja2 import Environment, PackageLoader
@@ -21,6 +22,10 @@ class GitRepositoryError(Exception):
 class OpenAIKeyError(Exception):
     """Custom exception for OpenAI API key errors."""
 
+
+class Llama2ServerError(Exception):
+    """Custom exception for Llama2 server errors."""
+
     pass
 
 
@@ -135,7 +140,7 @@ def get_commit_messages(directory: str) -> str:
 
 
 def generate_commit_message(
-    diff: str, start: str, ticket: str, api_key: str, model: str
+    diff: str, start: str, ticket: str, api_key: str, model: str, llama2_url: str = None
 ) -> str:
     """
     Generate a commit message.
@@ -152,6 +157,8 @@ def generate_commit_message(
         The OpenAI API key.
     model : str
         The OpenAI GPT model to use.
+    llama2_url: str
+        (Optional) The URL of the Llama2 server to use.
 
     Returns
     -------
@@ -176,23 +183,68 @@ def generate_commit_message(
         {"role": "system", "content": system_msg},
         {"role": "user", "content": user_msg},
     ]
-    openai.api_key = api_key
-    response = openai.ChatCompletion.create(model=model, messages=messages)
-    response = response.choices[0].message.content.strip()
 
-    # Strip the first line of response
-    # Assign it to start if it is empty
-    # Otherwise, remove the first line from the response
-    if start:
-        response = response.split("\n", 1)[1]
+    # Determine which service to use
+    if llama2_url:
+        # Call the Llama2 server
+        response = call_llama2_server(llama2_url, messages)
+        print(response)
+        response = response["choices"][0]["message"]["content"].strip()
     else:
-        start = response.split("\n", 1)[0]
-        response = response.split("\n", 1)[1]
+        # Use OpenAI's service
+        openai.api_key = api_key
+        response = openai.ChatCompletion.create(model=model, messages=messages)
+        response = response.choices[0].message.content.strip()
+
+    # Split the response by newline and store the result
+    split_response = response.split("\n", 1)
+
+    # Check if split_response contains at least 2 elements
+    if len(split_response) > 1:
+        response = split_response[1] if start else split_response[0]
+    else:
+        # If there is no newline, the whole response is either the start or the generated message
+        if not start:
+            start = response
+        # If start is already set, we leave response as is, or set it to an empty string
+        else:
+            response = ""
 
     # Render and return the template
     return render_final_template(start, response, ticket).strip()
 
 
+def call_llama2_server(url: str, messages: list) -> dict:
+    """
+    Call the Llama2 server.
+
+    Parameters
+    ----------
+    url : str
+        The URL of the Llama2 server.
+    messages : list
+        The messages to send to the server.
+
+    Returns
+    -------
+    dict
+        The response from the server.
+
+    Raises
+    ------
+    Llama2ServerError
+        If an error occurs while connecting to the server.
+    """
+    try:
+        response = requests.post(url, json={"messages": messages})
+        response.raise_for_status()
+        return response.json()
+    except requests.exceptions.RequestException as e:
+        raise Llama2ServerError(
+            f"An error occurred while connecting to the Llama2 server: {e}"
+        )
+
+
 def render_template(message: str, template_name: str) -> str:
     """
     Render the commit message template.
@@ -275,6 +327,7 @@ def run_magic_commit(
     api_key: str,
     model: str,
     show_loading_message: bool,
+    llama2_url: str = None,
 ) -> str:
     """
     Generate a commit message and return it.
@@ -293,6 +346,8 @@ def run_magic_commit(
         The OpenAI GPT model to use.
     show_loading_message : bool
         Whether or not to show the loading animation.
+    llama2_url: str
+        (Optional) The URL of the Llama2 server to use.
 
     Returns
     -------
@@ -309,7 +364,9 @@ def run_magic_commit(
         diff = run_git_diff(directory)
         if not check_git_status(directory):  # Check if there are staged changes
             return "⛔ Warning: No staged changes detected. Please stage some changes before running magic-commit."
-        commit_message = generate_commit_message(diff, start, ticket, api_key, model)
+        commit_message = generate_commit_message(
+            diff, start, ticket, api_key, model, llama2_url
+        )
     finally:
         # Ensure the loading animation stops
         if show_loading_message:
